# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/kinematics/JointJerks.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/kinematics/JointJerks.proto',
  package='rst.kinematics',
  syntax='proto2',
  serialized_pb=_b('\n\x1frst/kinematics/JointJerks.proto\x12\x0erst.kinematics\"\x1f\n\nJointJerks\x12\x11\n\x05jerks\x18\x01 \x03(\x02\x42\x02\x10\x01\x42\x10\x42\x0eJointJerksType')
)




_JOINTJERKS = _descriptor.Descriptor(
  name='JointJerks',
  full_name='rst.kinematics.JointJerks',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='jerks', full_name='rst.kinematics.JointJerks.jerks', index=0,
      number=1, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001'))),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=51,
  serialized_end=82,
)

DESCRIPTOR.message_types_by_name['JointJerks'] = _JOINTJERKS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

JointJerks = _reflection.GeneratedProtocolMessageType('JointJerks', (_message.Message,), dict(
  DESCRIPTOR = _JOINTJERKS,
  __module__ = 'rst.kinematics.JointJerks_pb2'
  # @@protoc_insertion_point(class_scope:rst.kinematics.JointJerks)
  ))
_sym_db.RegisterMessage(JointJerks)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\016JointJerksType'))
_JOINTJERKS.fields_by_name['jerks'].has_options = True
_JOINTJERKS.fields_by_name['jerks']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001'))
# @@protoc_insertion_point(module_scope)
