# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/vision/EncodedImage.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/vision/EncodedImage.proto',
  package='rst.vision',
  syntax='proto2',
  serialized_pb=_b('\n\x1drst/vision/EncodedImage.proto\x12\nrst.vision\"\x8b\x01\n\x0c\x45ncodedImage\x12\x33\n\x08\x65ncoding\x18\x02 \x02(\x0e\x32!.rst.vision.EncodedImage.Encoding\x12\x0c\n\x04\x64\x61ta\x18\x01 \x02(\x0c\"8\n\x08\x45ncoding\x12\x07\n\x03PPM\x10\x01\x12\x07\n\x03PNG\x10\x02\x12\x07\n\x03JPG\x10\x03\x12\x07\n\x03JP2\x10\x04\x12\x08\n\x04TIFF\x10\x05\x42\x12\x42\x10\x45ncodedImageType')
)



_ENCODEDIMAGE_ENCODING = _descriptor.EnumDescriptor(
  name='Encoding',
  full_name='rst.vision.EncodedImage.Encoding',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PPM', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PNG', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='JPG', index=2, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='JP2', index=3, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TIFF', index=4, number=5,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=129,
  serialized_end=185,
)
_sym_db.RegisterEnumDescriptor(_ENCODEDIMAGE_ENCODING)


_ENCODEDIMAGE = _descriptor.Descriptor(
  name='EncodedImage',
  full_name='rst.vision.EncodedImage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='encoding', full_name='rst.vision.EncodedImage.encoding', index=0,
      number=2, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='data', full_name='rst.vision.EncodedImage.data', index=1,
      number=1, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ENCODEDIMAGE_ENCODING,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=46,
  serialized_end=185,
)

_ENCODEDIMAGE.fields_by_name['encoding'].enum_type = _ENCODEDIMAGE_ENCODING
_ENCODEDIMAGE_ENCODING.containing_type = _ENCODEDIMAGE
DESCRIPTOR.message_types_by_name['EncodedImage'] = _ENCODEDIMAGE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

EncodedImage = _reflection.GeneratedProtocolMessageType('EncodedImage', (_message.Message,), dict(
  DESCRIPTOR = _ENCODEDIMAGE,
  __module__ = 'rst.vision.EncodedImage_pb2'
  # @@protoc_insertion_point(class_scope:rst.vision.EncodedImage)
  ))
_sym_db.RegisterMessage(EncodedImage)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\020EncodedImageType'))
# @@protoc_insertion_point(module_scope)
