# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/robot/ForceApplication.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.dynamics import Forces_pb2 as rst_dot_dynamics_dot_Forces__pb2
from rst.geometry import Translation_pb2 as rst_dot_geometry_dot_Translation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/robot/ForceApplication.proto',
  package='rst.robot',
  syntax='proto2',
  serialized_pb=_b('\n rst/robot/ForceApplication.proto\x12\trst.robot\x1a\x19rst/dynamics/Forces.proto\x1a\x1erst/geometry/Translation.proto\"{\n\x10\x46orceApplication\x12\x0c\n\x04link\x18\x01 \x02(\t\x12#\n\x05\x66orce\x18\x02 \x02(\x0b\x32\x14.rst.dynamics.Forces\x12\x34\n\x11\x61pplication_point\x18\x03 \x02(\x0b\x32\x19.rst.geometry.TranslationB\x16\x42\x14\x46orceApplicationType')
  ,
  dependencies=[rst_dot_dynamics_dot_Forces__pb2.DESCRIPTOR,rst_dot_geometry_dot_Translation__pb2.DESCRIPTOR,])




_FORCEAPPLICATION = _descriptor.Descriptor(
  name='ForceApplication',
  full_name='rst.robot.ForceApplication',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='link', full_name='rst.robot.ForceApplication.link', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='force', full_name='rst.robot.ForceApplication.force', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='application_point', full_name='rst.robot.ForceApplication.application_point', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=106,
  serialized_end=229,
)

_FORCEAPPLICATION.fields_by_name['force'].message_type = rst_dot_dynamics_dot_Forces__pb2._FORCES
_FORCEAPPLICATION.fields_by_name['application_point'].message_type = rst_dot_geometry_dot_Translation__pb2._TRANSLATION
DESCRIPTOR.message_types_by_name['ForceApplication'] = _FORCEAPPLICATION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ForceApplication = _reflection.GeneratedProtocolMessageType('ForceApplication', (_message.Message,), dict(
  DESCRIPTOR = _FORCEAPPLICATION,
  __module__ = 'rst.robot.ForceApplication_pb2'
  # @@protoc_insertion_point(class_scope:rst.robot.ForceApplication)
  ))
_sym_db.RegisterMessage(ForceApplication)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\024ForceApplicationType'))
# @@protoc_insertion_point(module_scope)
