# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/devices/flexirob/RobotStateCollection.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.devices.flexirob import RobotState_pb2 as rst_dot_devices_dot_flexirob_dot_RobotState__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/devices/flexirob/RobotStateCollection.proto',
  package='rst.devices.flexirob',
  syntax='proto2',
  serialized_pb=_b('\n/rst/devices/flexirob/RobotStateCollection.proto\x12\x14rst.devices.flexirob\x1a%rst/devices/flexirob/RobotState.proto\"I\n\x14RobotStateCollection\x12\x31\n\x07\x65lement\x18\x01 \x03(\x0b\x32 .rst.devices.flexirob.RobotStateB\x1a\x42\x18RobotStateCollectionType')
  ,
  dependencies=[rst_dot_devices_dot_flexirob_dot_RobotState__pb2.DESCRIPTOR,])




_ROBOTSTATECOLLECTION = _descriptor.Descriptor(
  name='RobotStateCollection',
  full_name='rst.devices.flexirob.RobotStateCollection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='element', full_name='rst.devices.flexirob.RobotStateCollection.element', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=112,
  serialized_end=185,
)

_ROBOTSTATECOLLECTION.fields_by_name['element'].message_type = rst_dot_devices_dot_flexirob_dot_RobotState__pb2._ROBOTSTATE
DESCRIPTOR.message_types_by_name['RobotStateCollection'] = _ROBOTSTATECOLLECTION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RobotStateCollection = _reflection.GeneratedProtocolMessageType('RobotStateCollection', (_message.Message,), dict(
  DESCRIPTOR = _ROBOTSTATECOLLECTION,
  __module__ = 'rst.devices.flexirob.RobotStateCollection_pb2'
  # @@protoc_insertion_point(class_scope:rst.devices.flexirob.RobotStateCollection)
  ))
_sym_db.RegisterMessage(RobotStateCollection)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\030RobotStateCollectionType'))
# @@protoc_insertion_point(module_scope)
